@@ -147,6 +147,12 @@ double solveLinB(rx_solve *rx, unsigned int id, double t, int linCmt,
       F = d_F2;
     }
     switch(whI){
+    case 5: // multiply
+      error("Multiplication events not currently supported with RxODE solved systems.");
+      break;
+    case 4: // replace
+      error("Replacement events are not currently supported with RxODE solved systems.");
+      break;    
     case 7:
       continue;
     case 6:
@@ -182,7 +188,19 @@ double solveLinB(rx_solve *rx, unsigned int id, double t, int linCmt,
 	error("You cannot turn off a compartment with a solved system.");
       }
       // Steady state
-      if (ISNA(dose)){
+      if (wh0 == 40 && dose > 0){
+	tT = t - ind->all_times[ind->idose[l]];
+	thisT = tT;
+	rate = dose;
+	cur += rate*A*alpha1*exp(-alpha*thisT);
+	if (ncmt >= 2){
+	  cur += rate*B*beta1*exp(-beta*thisT);
+	  if (ncmt >= 3){
+	    cur += rate*C*gamma1*exp(-gamma*thisT);
+	  }
+	}
+	return (ret+cur);
+      } else if (ISNA(dose)){
       } else if (dose > 0){
 	// During infusion
 	tT = t - ind->all_times[ind->idose[l]] ;
